
# Version 0.1.1

+ Add docs
+ Add tests
+ Add citation
+ Add Github Action
+ Add engineering problems from papers:
  + Prairie Dog Optimization Algorithm (pdo_2022)
  + A Test-suite of Non-Convex Constrained Optimization Problems from the Real-World and Some Baseline Results (rwco_2020)


---------------------------------------------------------------------

# Version 0.1.0 (First version)

+ Add project, Selector class, utils module.
+ Add wrapper module:
  + sequential-based
  + recursive-based
  + mha-based

